@@ -1,7 +1,7 @@
 # coding=utf-8
 '''
 virtual-touchpad
-Copyright (C) 2013 Moses Palmér
+Copyright (C) 2013-2014 Moses Palmér
 
 This program is free software: you can redistribute it and/or modify it under
 the terms of the GNU General Public License as published by the Free Software
@@ -19,7 +19,7 @@ this program. If not, see <http://www.gnu.org/licenses/>.
 from ._info import *
 
 import gevent
-from gevent import monkey; monkey.patch_all()
+from gevent import monkey; monkey.patch_all(thread = False)
 
 import bottle
 import geventwebsocket
@@ -30,6 +30,8 @@ import pkg_resources
 import sys
 import time
 
+from _platform import *
+
 try:
     from geventwebsocket.handler import WebSocketHandler
 except ImportError:
